@@ -75,6 +75,7 @@ from .usecases.underwater_pollution_detection import UnderwaterPlasticConfig
 from .usecases.pedestrian_detection import PedestrianDetectionConfig
 from .usecases.age_detection import AgeDetectionConfig
 from .usecases.mask_detection import MaskDetectionConfig
+from .usecases.chicken_pose_detection import ChickenPoseDetectionConfig
 
 
 from .usecases.weld_defect_detection import WeldDefectConfig
@@ -83,6 +84,9 @@ from .usecases.car_damage_detection import CarDamageConfig
 from .usecases.price_tag_detection import PriceTagConfig
 from .usecases.banana_defect_detection import BananaMonitoringConfig
 from .usecases.distracted_driver_detection import DistractedDriverConfig
+from .usecases.emergency_vehicle_detection import EmergencyVehicleConfig
+from .usecases.solar_panel import SolarPanelConfig
+from .usecases.crop_weed_detection import CropWeedDetectionConfig
 
 # Use case implementations
 from .usecases import (
@@ -107,7 +111,11 @@ from .usecases import (
     BananaMonitoringUseCase,
     WeldDefectUseCase,
     PriceTagUseCase,
-    DistractedDriverUseCase
+    DistractedDriverUseCase,
+    EmergencyVehicleUseCase,
+    SolarPanelUseCase,
+    ChickenPoseDetectionUseCase,
+    CropWeedDetectionUseCase
 )
 
 # Register use cases automatically
@@ -129,11 +137,15 @@ _pedestrian_detection = PedestrianDetectionUseCase()
 _age_detection = AgeDetectionUseCase()
 _mask_detection = MaskDetectionUseCase()
 _banana_defect_detection = BananaMonitoringUseCase()
+_chicken_pose_detection = ChickenPoseDetectionUseCase()
 
 _weld_defect_detection = WeldDefectUseCase()
 _pricetag_detection = PriceTagUseCase()
 _car_damage = CarDamageDetectionUseCase()
 _distracted_driver = DistractedDriverUseCase()
+_emergency_vehicle_detection = EmergencyVehicleUseCase()
+_solar_panel = SolarPanelUseCase()
+_crop_weed_detection = CropWeedDetectionUseCase()
 
 registry.register_use_case(_people_counting.category, _people_counting.name, PeopleCountingUseCase)
 registry.register_use_case(_customer_service.category, _customer_service.name, CustomerServiceUseCase)
@@ -155,10 +167,16 @@ registry.register_use_case(_pricetag_detection.category, _pricetag_detection.nam
 registry.register_use_case(_weld_defect_detection.category, _weld_defect_detection.name, WeldDefectUseCase  )
 registry.register_use_case(_mask_detection.category, _mask_detection.name, MaskDetectionUseCase)
 registry.register_use_case(_banana_defect_detection.category, _banana_defect_detection.name, BananaMonitoringUseCase)
+registry.register_use_case(_chicken_pose_detection.category, _chicken_pose_detection.name, ChickenPoseDetectionUseCase)
+
 
 registry.register_use_case(_car_damage.category, _car_damage.name, CarDamageDetectionUseCase)
 registry.register_use_case(_distracted_driver.category, _distracted_driver.name, DistractedDriverUseCase)
 
+registry.register_use_case(_emergency_vehicle_detection.category, _emergency_vehicle_detection.name, EmergencyVehicleUseCase)
+registry.register_use_case(_solar_panel.category, _solar_panel.name, SolarPanelUseCase)
+registry.register_use_case(_crop_weed_detection.category, _crop_weed_detection.name, CropWeedDetectionUseCase)
+
 # Utility functions - organized by category
 from .utils import (  # noqa: E402
     # Geometry utilities
@@ -311,6 +329,10 @@ __all__ = [
     'PriceTagConfig',
     'BananaMonitoringConfig',
     'DistractedDriverConfig',
+    'EmergencyVehicleConfig',
+    'SolarPanelConfig',
+    'ChickenPoseDetectionConfig',
+    'CropWeedDetectionConfig',
 
     # Use case classes
     'PeopleCountingUseCase',
@@ -335,6 +357,10 @@ __all__ = [
     'BananaMonitoringUseCase',
     'PriceTagUseCase',
     'DistractedDriverUseCase',
+    'EmergencyVehicleUseCase',
+    'SolarPanelUseCase',
+    'ChickenPoseDetectionUseCase',
+    'CropWeedDetectionUseCase',
     
     # Base classes for extension
     'BaseProcessor',
