@@ -27,6 +27,10 @@ from ..usecases.price_tag_detection import PriceTagUseCase, PriceTagConfig
 from ..usecases.mask_detection import MaskDetectionConfig, MaskDetectionUseCase
 from ..usecases.banana_defect_detection import BananaMonitoringUseCase,BananaMonitoringConfig
 from ..usecases.distracted_driver_detection import DistractedDriverUseCase, DistractedDriverConfig
+from ..usecases.emergency_vehicle_detection import EmergencyVehicleUseCase, EmergencyVehicleConfig
+from ..usecases.solar_panel import SolarPanelUseCase, SolarPanelConfig
+from ..usecases.chicken_pose_detection import ChickenPoseDetectionUseCase,ChickenPoseDetectionConfig
+from ..usecases.crop_weed_detection import CropWeedDetectionUseCase, CropWeedDetectionConfig
 
 __all__ = [
     'PeopleCountingUseCase',
@@ -51,6 +55,10 @@ __all__ = [
     'WeldDefectUseCase',
     'PriceTagUseCase',
     'DistractedDriverUseCase',
+    'EmergencyVehicleUseCase',
+    'ChickenPoseDetectionUseCase',
+    'SolarPanelUseCase',
+    'CropWeedDetectionUseCase',
     'PeopleCountingConfig',
     'PotholeConfig',
     'BananaMonitoringConfig',
@@ -71,5 +79,9 @@ __all__ = [
     'AgeDetectionConfig',
     'WeldDefectConfig',
     'PriceTagConfig',
-    'DistractedDriverConfig'
+    'DistractedDriverConfig',
+    'EmergencyVehicleConfig',
+    'ChickenPoseDetectionConfig',
+    'SolarPanelConfig',
+    'CropWeedDetectionConfig'
 ]
