@@ -404,6 +404,11 @@ class ConfigManager:
             "car_damage_detection":None,
             "weld_defect_detection" : None,
             "banana_defect_detection" : None,
+            "chicken_pose_detection" : None,
+            "solar_panel": None,
+            "crop_weed_detection": None,
+            "emergency_vehicle_detection": None,
+            "price_tag_detection": None
         }
 
     def register_config_class(self, usecase: str, config_class: type) -> None:
@@ -433,6 +438,14 @@ class ConfigManager:
             return BananaMonitoringConfig
         except ImportError:
             return None
+        
+    def chicken_pose_detection_config_class(self):
+        """Get Chicken pose monitoring class to avoid circular imports."""
+        try:
+            from ..usecases.chicken_pose_detection import ChickenPoseDetectionConfig
+            return ChickenPoseDetectionConfig
+        except ImportError:
+            return None
 
     def _get_fire_smoke_detection_config_class(self):
         """Register a configuration class for a use case."""
@@ -441,6 +454,7 @@ class ConfigManager:
             return FireSmokeConfig
         except ImportError:
             return None
+    
 
     def _get_car_damage_config_class(self):
         """Register a configuration class for a use case."""
@@ -537,6 +551,30 @@ class ConfigManager:
             return DistractedDriverConfig
         except ImportError:
             return None
+        
+    def emergency_vehicle_detection_config_class(self):
+        """Register a configuration class for a use case."""
+        try:
+            from ..usecases.emergency_vehicle_detection import EmergencyVehicleConfig
+            return EmergencyVehicleConfig
+        except ImportError:
+            return None
+    
+    def solar_panel_config_class(self):
+        """Register a configuration class for a use case."""
+        try:
+            from ..usecases.solar_panel import SolarPanelConfig
+            return SolarPanelConfig
+        except ImportError:
+            return None
+        
+    def crop_weed_detection_config_class(self):
+        """Register a configuration class for a use case."""
+        try:
+            from ..usecases.crop_weed_detection import CropWeedDetectionConfig
+            return CropWeedDetectionConfig
+        except ImportError:
+            return None
 
     def create_config(self, usecase: str, category: Optional[str] = None, **kwargs) -> BaseConfig:
         """
@@ -687,6 +725,22 @@ class ConfigManager:
                 alert_config=alert_config,
                 **kwargs
             )
+        
+        elif usecase == "solar_panel":
+            # Import here to avoid circular import
+            from ..usecases.solar_panel import SolarPanelConfig
+
+            # Handle nested configurations
+            alert_config = kwargs.pop("alert_config", None)
+            if alert_config and isinstance(alert_config, dict):
+                alert_config = AlertConfig(**alert_config)
+
+            config = SolarPanelConfig(
+                category=category or "energy",
+                usecase=usecase,
+                alert_config=alert_config,
+                **kwargs
+            )
 
         elif usecase == "car_damage_detection":
             # Import here to avoid circular import
@@ -737,6 +791,22 @@ class ConfigManager:
                 **kwargs
             )
 
+        elif usecase == "chicken_pose_detection":
+            # Import here to avoid circular import
+            from ..usecases.chicken_pose_detection import ChickenPoseDetectionConfig
+
+            # Handle nested configurations
+            alert_config = kwargs.pop("alert_config", None)
+            if alert_config and isinstance(alert_config, dict):
+                alert_config = AlertConfig(**alert_config)
+
+            config = ChickenPoseDetectionConfig(
+                category=category or "agriculture",
+                usecase=usecase,
+                alert_config=alert_config,
+                **kwargs
+            )
+
         elif usecase == "fruit_monitoring":
             # Import here to avoid circular import
             from ..usecases.banana_defect_detection import BananaMonitoringConfig
@@ -928,6 +998,38 @@ class ConfigManager:
                 alert_config=alert_config,
                 **kwargs
             )
+
+        elif usecase == "emergency_vehicle_detection":
+            # Import here to avoid circular import
+            from ..usecases.emergency_vehicle_detection import EmergencyVehicleConfig
+
+            # Handle nested configurations
+            alert_config = kwargs.pop("alert_config", None)
+            if alert_config and isinstance(alert_config, dict):
+                alert_config = AlertConfig(**alert_config)
+
+            config = EmergencyVehicleConfig(
+                category=category or "traffic",
+                usecase=usecase,
+                alert_config=alert_config,
+                **kwargs
+            )
+
+        elif usecase == "crop_weed_detection":
+            # Import here to avoid circular import
+            from ..usecases.crop_weed_detection import CropWeedDetectionConfig
+
+            # Handle nested configurations
+            alert_config = kwargs.pop("alert_config", None)
+            if alert_config and isinstance(alert_config, dict):
+                alert_config = AlertConfig(**alert_config)
+
+            config = CropWeedDetectionConfig(
+                category=category or "agriculture",
+                usecase=usecase,
+                alert_config=alert_config,
+                **kwargs
+            )
             
         else:
             raise ConfigValidationError(f"Unknown use case: {usecase}")
@@ -1046,6 +1148,12 @@ class ConfigManager:
             default_config = FireSmokeConfig()
             return default_config.to_dict()
 
+        elif usecase == "solar_panel":
+            # Import here to avoid circular import
+            from ..usecases.solar_panel import SolarPanelConfig
+            default_config = SolarPanelConfig()
+            return default_config.to_dict()
+
         elif usecase == "car_damage_detection":
             # Import here to avoid circular import
             from ..usecases.car_damage_detection import CarDamageConfig
@@ -1064,6 +1172,12 @@ class ConfigManager:
             default_config = VehicleMonitoringConfig()
             return default_config.to_dict()
         
+        elif usecase == "chicken_pose_detection":
+            # Import here to avoid circular import
+            from ..usecases.chicken_pose_detection import ChickenPoseDetectionConfig
+            default_config = ChickenPoseDetectionConfig()
+            return default_config.to_dict()
+        
         elif usecase == "fruit_monitoring":
             # Import here to avoid circular import
             from ..usecases.banana_defect_detection import BananaMonitoringConfig
@@ -1123,6 +1237,17 @@ class ConfigManager:
             from ..usecases.distracted_driver_detection import DistractedDriverConfig
             default_config = DistractedDriverConfig()
             return default_config.to_dict()
+        elif usecase == "emergency_vehicle_detection":
+            # Import here to avoid circular import
+            from ..usecases.emergency_vehicle_detection import EmergencyVehicleConfig
+            default_config = EmergencyVehicleConfig()
+            return default_config.to_dict()
+        elif usecase == "crop_weed_detection":
+            # Import here to avoid circular import
+            from ..usecases.crop_weed_detection import CropWeedDetectionConfig
+            default_config = CropWeedDetectionConfig()
+            return default_config.to_dict()
+
         elif usecase not in self._config_classes:
             raise ConfigValidationError(f"Unsupported use case: {usecase}")
 
