@@ -45,13 +45,17 @@ from .usecases import (
     FaceEmotionUseCase,
     UnderwaterPlasticUseCase,
     PedestrianDetectionUseCase,
+    ChickenPoseDetectionUseCase,
 
     AgeDetectionUseCase,
     WeldDefectUseCase,
 
     AgeDetectionUseCase,
     PriceTagUseCase,
-    DistractedDriverUseCase
+    DistractedDriverUseCase,
+    EmergencyVehicleUseCase,
+    SolarPanelUseCase,
+    CropWeedDetectionUseCase
 
 
 )
@@ -137,6 +141,10 @@ class PostProcessor:
         registry.register_use_case("price_tag", "price_tag_detection", PriceTagUseCase)
         registry.register_use_case("mask_detection", "mask_detection", MaskDetectionUseCase)
         registry.register_use_case("automobile", "distracted_driver_detection", DistractedDriverUseCase)
+        registry.register_use_case("traffic", "emergency_vehicle_detection", EmergencyVehicleUseCase)
+        registry.register_use_case("energy", "solar_panel", SolarPanelUseCase)
+        registry.register_use_case("agriculture", "chicken_pose_detection", ChickenPoseDetectionUseCase)
+        registry.register_use_case("agriculture", "crop_weed_detection", CropWeedDetectionUseCase)
         
         logger.debug("Registered use cases with registry")
     
@@ -233,10 +241,18 @@ class PostProcessor:
                 result = use_case.process(data, parsed_config, context, stream_info)
             elif isinstance(use_case, BananaMonitoringUseCase):
                 result = use_case.process(data, parsed_config, context, stream_info)
+            elif isinstance(use_case, ChickenPoseDetectionUseCase):
+                result = use_case.process(data, parsed_config, context, stream_info)
             elif isinstance(use_case, FlareAnalysisUseCase):
                 result = use_case.process(data, parsed_config,input_bytes, context, stream_info)
             elif isinstance(use_case,LicensePlateUseCase):
                 result = use_case.process(data, parsed_config, context, stream_info)
+            elif isinstance(use_case, CropWeedDetectionUseCase):
+                result = use_case.process(data, parsed_config, context, stream_info)
+            elif isinstance(use_case, EmergencyVehicleUseCase): 
+                result = use_case.process(data, parsed_config, context, stream_info)
+            elif isinstance(use_case, PriceTagUseCase):
+                result = use_case.process(data, parsed_config, context, stream_info)
             else:
                 result = use_case.process(data, parsed_config, context, stream_info)
             
