@@ -29,6 +29,10 @@ from .car_damage_detection import CarDamageConfig, CarDamageDetectionUseCase
 from .price_tag_detection import PriceTagConfig, PriceTagUseCase
 from .mask_detection import MaskDetectionConfig, MaskDetectionUseCase
 from .distracted_driver_detection import DistractedDriverUseCase, DistractedDriverConfig
+from .emergency_vehicle_detection import EmergencyVehicleUseCase, EmergencyVehicleConfig
+from .solar_panel import SolarPanelUseCase, SolarPanelConfig
+from .chicken_pose_detection import ChickenPoseDetectionConfig,ChickenPoseDetectionUseCase
+from .crop_weed_detection import CropWeedDetectionConfig, CropWeedDetectionUseCase
 
 
 __all__ = [
@@ -54,6 +58,10 @@ __all__ = [
     'WeldDefectUseCase',
     'PriceTagUseCase',
     'DistractedDriverUseCase',
+    'EmergencyVehicleUseCase',
+    'SolarPanelUseCase',
+    'ChickenPoseDetectionUseCase',
+    'CropWeedDetectionUseCase',
     'PeopleCountingConfig',
     'ParkingSpaceConfig',
     'CustomerServiceConfig',
@@ -70,9 +78,13 @@ __all__ = [
     'FaceEmotionConfig',
     'UnderwaterPlasticConfig',
     'PedestrianDetectionConfig',
+    'ChickenPoseDetectionConfig',
     'AgeDetectionConfig',
     'BananaMonitoringConfig',
     'WeldDefectConfig',
     'PriceTagConfig',
     'DistractedDriverConfig',
+    'EmergencyVehicleConfig',
+    'SolarPanelConfig',
+    'CropWeedDetectionConfig'
 ]
\ No newline at end of file
